"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _default;

var _nightmare = _interopRequireDefault(require("nightmare"));

var _twitterUrlParser = _interopRequireDefault(require("twitter-url-parser"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _default(tweetUrl, filePath) {
  return new Promise(function (resolve, reject) {
    var tweetId = function () {
      try {
        return (0, _twitterUrlParser.default)(tweetUrl).id;
      } catch (error) {
        throw new Error('Invalid tweet URL.');
      }
    }();

    var tweetSelector = ".tweet[data-tweet-id=\"".concat(tweetId, "\"]");
    var sensitivityButtonSelector = "".concat(tweetSelector, " button.js-display-this-media");
    var mediaSelector = "".concat(tweetSelector, " .AdaptiveMedia");
    var iframeSelector = "".concat(tweetSelector, " iframe");
    var nightmare = new _nightmare.default();
    Promise.resolve().then(function () {
      return nightmare.viewport(2000, 2000);
    }).then(function () {
      return nightmare.goto(tweetUrl);
    }).then(function () {
      return nightmare.wait(function () {
        return document.readyState === "complete";
      });
    }).then(function () {
      return nightmare.exists(tweetSelector);
    }).then(function (hasTweet) {
      if (!hasTweet) throw new Error('Tweet does not exist!');
    }).then(function () {
      return nightmare.exists(sensitivityButtonSelector);
    }).then(function (hasSensitivityButton) {
      return hasSensitivityButton && nightmare.click(sensitivityButtonSelector);
    }).then(function () {
      return nightmare.exists(mediaSelector);
    }).then(function (hasMedia) {
      return hasMedia && nightmare.waitUntilVisible(mediaSelector);
    }).then(function () {
      return nightmare.exists(iframeSelector);
    }).then(function (hasIframe) {
      return hasIframe && nightmare.waitUntilVisible(iframeSelector);
    }).then(function () {
      return nightmare.style(tweetSelector, {
        borderRadius: "0px"
      });
    }) // Ensure tweet completely fills screenshot.
    .then(function () {
      return nightmare.boundingBox(tweetSelector);
    }).then(function (boundingBox) {
      return nightmare.screenshot(filePath, boundingBox).end();
    }).then(resolve).catch(reject);
  });
}

_nightmare.default.action("waitUntilVisible", function (selector, done) {
  var _this = this;

  this.wait(selector).then(function () {
    return _this.wait(function (selector) {
      var element = document.querySelector(selector);
      return element.offsetWidth > 0 && element.offsetHeight > 0;
    }, selector);
  }).then(done);
});

_nightmare.default.action("style", function (selector, style, done) {
  this.evaluate_now(function (selector, style) {
    var element = document.querySelector(selector);
    Object.assign(element.style, style);
  }, done, selector, style);
});

_nightmare.default.action("boundingBox", function (selector, done) {
  this.evaluate_now(function (selector) {
    var element = document.querySelector(selector);
    var rectangle = element.getBoundingClientRect();
    return {
      x: Math.round(rectangle.left),
      y: Math.round(rectangle.top),
      width: Math.round(rectangle.width),
      height: Math.round(rectangle.height)
    };
  }, done, selector);
});